# Copyright 2025 Canonical Ltd.
# See LICENSE file for licensing details.

"""Utilities to work with litmus."""

from .models import DatabaseConfig
from .utils import get_app_hostname

__all__ = ["DatabaseConfig", "get_app_hostname"]



# Copyright 2025 Canonical Ltd.
# See LICENSE file for licensing details.

import pytest
from ops.testing import Relation


@pytest.fixture(scope="function")
def litmus_auth():
    return Relation("litmus-auth")
